@@ -1,8 +1,10 @@
 use super::world_socket::WriterMessage;
 use crate::error::{Error, Result};
 use crate::packet::{to_bytes, Packet};
+use crate::server::world_socket::ContainerBytes;
 use async_trait::async_trait;
-use bytes::Bytes;
+use crossbeam::atomic::AtomicCell;
+use easy_pool::PoolObjectContainer;
 #[cfg(feature = "flatbuffers_helpers")]
 use flatbuffers::FlatBufferBuilder;
 use std::{
@@ -38,6 +40,7 @@ pub struct SocketTools {
     pub(crate) tx: UnboundedSender<WriterMessage>,
     pub id: u64,
     pub(crate) latency: AtomicI64,
+    closed: AtomicCell<bool>,
 }
 
 impl SocketTools {
@@ -51,6 +54,7 @@ impl SocketTools {
             tx,
             id,
             latency: AtomicI64::new(0),
+            closed: AtomicCell::new(false),
         }
     }
 
@@ -68,7 +72,7 @@ impl SocketTools {
             let bytes = to_bytes(cmd, payload);
             if self
                 .tx
-                .send(WriterMessage::Send(bytes.freeze(), true))
+                .send(WriterMessage::Send(bytes.into(), true))
                 .is_err()
             {
                 log::error!("Can't send the data to the channel.");
@@ -83,17 +87,17 @@ impl SocketTools {
     /// use rollo::packet::to_bytes;
     ///
     /// fn on_message(socket: SocketTools) {
-    ///     let bytes = to_bytes(1, None).freeze();
-    ///     socket.send_data(bytes);
+    ///     let bytes = to_bytes(1, None);
+    ///     socket.send_data(bytes.into());
     /// }
     /// ```
-    pub fn send_data(&self, bytes: Bytes) {
+    pub fn send_data(&self, bytes: ContainerBytes) {
         if !self.is_closed() && self.tx.send(WriterMessage::Send(bytes, true)).is_err() {
             log::error!("Can't send the data to the channel.");
         }
     }
 
-    pub fn write_data(&self, bytes: Bytes) {
+    pub fn write_data(&self, bytes: ContainerBytes) {
         if !self.is_closed() && self.tx.send(WriterMessage::Send(bytes, false)).is_err() {
             log::error!("Can't send the data to the channel.");
         }
@@ -120,7 +124,7 @@ impl SocketTools {
 
     #[cfg(feature = "flatbuffers_helpers")]
     pub fn send_flatbuffers<
-        F: 'static + Fn(&mut FlatBufferBuilder<'static>) -> Bytes + Send + Sync,
+        F: 'static + Fn(&mut FlatBufferBuilder<'static>) -> PoolObjectContainer<Vec<u8>> + Send + Sync,
     >(
         &self,
         f: F,
@@ -146,6 +150,7 @@ impl SocketTools {
     /// }
     /// ```
     pub fn close(&self) -> Result<()> {
+        self.closed.store(true);
         self.tx
             .send(WriterMessage::Close)
             .map_err(|_| Error::Channel)
@@ -181,7 +186,7 @@ impl SocketTools {
     /// }
     /// ```
     pub fn is_closed(&self) -> bool {
-        self.tx.is_closed()
+        self.tx.is_closed() || self.closed.load()
     }
 }
 
@@ -192,6 +197,7 @@ impl Clone for SocketTools {
             tx: self.tx.clone(),
             id: self.id,
             socket_addr: self.socket_addr,
+            closed: AtomicCell::new(self.closed.load()),
         }
     }
 }
@@ -202,3 +208,15 @@ impl PartialEq for SocketTools {
     }
 }
 impl Eq for SocketTools {}
+
+impl From<PoolObjectContainer<Vec<u8>>> for ContainerBytes {
+    fn from(b: PoolObjectContainer<Vec<u8>>) -> Self {
+        ContainerBytes::Raw(b)
+    }
+}
+
+impl From<Arc<PoolObjectContainer<Vec<u8>>>> for ContainerBytes {
+    fn from(b: Arc<PoolObjectContainer<Vec<u8>>>) -> Self {
+        ContainerBytes::Arc(b)
+    }
+}
